MediaStreamAudioDestinationNode class


MediaStreamAudioDestinationNode


The MediaStreamAudioDestinationNode interface represents an audio destination consisting of a WebRTC MediaStream with a single AudioMediaStreamTrack, which can be used in a similar way to a MediaStream obtained from Navigator.getUserMedia().

It is an AudioNode that acts as an audio destination, created using the AudioContext.createMediaStreamDestination() method.

  • Number of inputs 1
  • Number of outputs 0
  • Channel count 2
  • Channel count mode "explicit"
  • Channel count interpretation "speakers"
Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited