OscillatorNode class


OscillatorNode


The OscillatorNode interface represents a periodic waveform, such as a sine wave. It is an AudioScheduledSourceNode audio-processing module that causes a specified frequency of a given wave to be created—in effect, a constant tone.

  • Number of inputs 0
  • Number of outputs 1
  • Channel count mode max
  • Channel count 2 (not used in the default count mode)
  • Channel interpretation speakers
Inheritance

Constructors

OscillatorNode()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited