public/web_audio library WAA
A Web Audio API port on Flutter Mobiles and Flutter Desktop.
This library is a copy and paste from the Flutter Web Audio Library interface,
but runs under Flutter Mobiles and Flutter Desktop instead of Flutter Web.
The goal is to be able to execute a Web App under iOS/Android with just an update
of the import statement.
Note : if we have to deviate from the original interface, those divergence will
be explicitly list here :
- AudioParamMap is a class specific on Flutter and does not have any correspondence in the W3C Recommandation
- AudioTrack is a class specific on Flutter and does not have any correspondence in the W3C Recommandation
- AudioTrackList is a class specific on Flutter and does not have any correspondence in the W3C Recommandation
- ScriptProcessorNode is a class specific on Flutter and does not have any correspondence in the W3C Recommandation
- The W3C AudioContextOptions class is not implemented
- The W3C AudioNodeOptions class is not implemented
- The W3C AudioWorklet class is not implemented
- The W3C MediaStreamTrackAudioSourceNode class is not implemented
Classes
- AnalyserNode
- AudioBuffer
- AudioBufferSourceNode
- AudioContext
- AudioDestinationNode
- AudioListener
- AudioNode
- AudioParam
- AudioParamMap
- AudioProcessingEvent
- AudioScheduledSourceNode
- AudioTrack
- AudioTrackList
- AudioWorkletGlobalScope
- AudioWorkletNode
- AudioWorkletProcessor
- BaseAudioContext
- BiquadFilterNode
- ChannelMergerNode
- ChannelSplitterNode
- ConstantSourceNode
- ConvolverNode
- DelayNode
- DynamicsCompressorNode
- GainNode
- IirFilterNode
- MediaElementAudioSourceNode
- MediaStreamAudioDestinationNode
- MediaStreamAudioSourceNode
- OfflineAudioCompletionEvent
- OfflineAudioContext
- OscillatorNode
- PannerNode
- PeriodicWave
- ScriptProcessorNode
- StereoPannerNode
- WaveShaperNode