DelayNode class
DelayNode
The DelayNode interface represents a delay-line an AudioNode audio-processing module that causes a delay between the arrival of an input data and its propagation to the output.
A DelayNode always has exactly one input and one output, both with the same amount of channels.
The DelayNode acts as a delay-line, here with a value of 1s.
When creating a graph that has a cycle, it is mandatory to have at least one DelayNode in the cycle, or the nodes taking part in the cycle will be muted.
- Number of inputs 1
- Number of outputs 1
- Channel count mode "max"
- Channel count 2 (not used in the default count mode)
- Channel interpretation "speakers"
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited