WaveShaperNode class
WaveShaperNode
The WaveShaperNode interface represents a non-linear distorter.
It is an AudioNode that uses a curve to apply a wave shaping distortion to the signal. Beside obvious distortion effects, it is often used to add a warm feeling to the signal.
A WaveShaperNode always has exactly one input and one output.
- Number of inputs 1
- Number of outputs 1
- Channel count mode "max"
- Channel count 2 (not used in the default count mode)
- Channel interpretation "speakers"
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited